@@ -64,7 +64,7 @@ void rs_emit_literal_cmd(rs_job_t *job, int len)
         rs_trace("emit LITERAL_N4(len=%d), cmd_byte=%#04x", len, cmd);
     }
 
-    rs_squirt_byte(job, cmd);
+    rs_squirt_byte(job, (rs_byte_t)cmd);
     if (param_len)
         rs_squirt_netint(job, len, param_len);
 
@@ -95,7 +95,6 @@ void rs_emit_copy_cmd(rs_job_t *job, rs_long_t where, rs_long_t len)
         assert(where_bytes == 1);
         cmd = RS_OP_COPY_N1_N1;
     }
-
     if (len_bytes == 1) ;
     else if (len_bytes == 2)
         cmd += 1;
@@ -108,15 +107,13 @@ void rs_emit_copy_cmd(rs_job_t *job, rs_long_t where, rs_long_t len)
 
     rs_trace("emit COPY_N%d_N%d(where=" FMT_LONG ", len=" FMT_LONG
              "), cmd_byte=%#04x", where_bytes, len_bytes, where, len, cmd);
-    rs_squirt_byte(job, cmd);
+    rs_squirt_byte(job, (rs_byte_t)cmd);
     rs_squirt_netint(job, where, where_bytes);
     rs_squirt_netint(job, len, len_bytes);
 
     stats->copy_cmds++;
     stats->copy_bytes += len;
     stats->copy_cmdbytes += 1 + where_bytes + len_bytes;
-
-    /* \todo All the stats */
 }
 
 /** Write an END command. */
@@ -125,5 +122,5 @@ void rs_emit_end_cmd(rs_job_t *job)
     int cmd = RS_OP_END;
 
     rs_trace("emit END, cmd_byte=%#04x", cmd);
-    rs_squirt_byte(job, cmd);
+    rs_squirt_byte(job, (rs_byte_t)cmd);
 }
