@@ -41,6 +41,9 @@
 #ifdef HAVE_SYS_STAT_H
 #  include <sys/stat.h>
 #endif
+#ifdef HAVE_IO_H
+#  include <io.h>
+#endif
 #include "librsync.h"
 #include "trace.h"
 
@@ -68,8 +71,8 @@
 #  define S_ISREG(x) ((x) & _S_IFREG)
 #endif
 
-/* Use _fileno if it exists and fileno doesn't. */
-#if !defined(HAVE_FILENO) && defined(HAVE__FILENO)
+/* Use and prefer _fileno if it exists. */
+#ifdef HAVE__FILENO
 #  define fileno(f) _fileno((f))
 #endif
 
@@ -129,23 +132,20 @@ rs_long_t rs_file_size(FILE *f)
 
 rs_result rs_file_copy_cb(void *arg, rs_long_t pos, size_t *len, void **buf)
 {
-    int got;
     FILE *f = (FILE *)arg;
 
     if (fseek(f, pos, SEEK_SET)) {
         rs_error("seek failed: %s", strerror(errno));
         return RS_IO_ERROR;
     }
-
-    got = fread(*buf, 1, *len, f);
-    if (got == -1) {
+    *len = fread(*buf, 1, *len, f);
+    if (*len) {
+        return RS_DONE;
+    } else if (ferror(f)) {
         rs_error("read error: %s", strerror(errno));
         return RS_IO_ERROR;
-    } else if (got == 0) {
+    } else {
         rs_error("unexpected eof on fd%d", fileno(f));
         return RS_INPUT_ENDED;
-    } else {
-        *len = got;
-        return RS_DONE;
     }
 }
