@@ -25,7 +25,8 @@
                                | sheltering.
                                */
 
-/** \file job.c Generic state-machine interface.
+/** \file job.c
+ * Generic state-machine interface.
  *
  * The point of this is that we need to be able to suspend and resume
  * processing at any point at which the buffers may block.
@@ -33,22 +34,18 @@
  * \sa \ref api_streaming \sa rs_job_iter() \sa ::rs_job */
 
 #include "config.h"
-
-#include <stdlib.h>
 #include <assert.h>
-#include <stdio.h>
+#include <stdlib.h>
 #include <time.h>
-
 #include "librsync.h"
-#include "stream.h"
-#include "util.h"
-#include "sumset.h"
 #include "job.h"
+#include "stream.h"
 #include "trace.h"
+#include "util.h"
 
 static rs_result rs_job_work(rs_job_t *job, rs_buffers_t *buffers);
 
-rs_job_t *rs_job_new(char const *job_name, rs_result (*statefn) (rs_job_t *))
+rs_job_t *rs_job_new(char const *job_name, rs_result (*statefn)(rs_job_t *))
 {
     rs_job_t *job;
 
