@@ -33,17 +33,14 @@
                                | Arco, and have a nice day.
                                */
 
-/** \file msg.c error messages for re_result values.
+/** \file msg.c
+ * error messages for re_result values.
  *
  * \todo (Suggestion by tridge) Add a function which outputs a complete text
  * description of a job, including only the fields relevant to the current
  * encoding function. */
 
 #include "config.h"
-
-#include <stdlib.h>
-#include <stdio.h>
-
 #include "librsync.h"
 
 char const *rs_strerror(rs_result r)
