@@ -34,7 +34,7 @@
 typedef struct rs_prototab_ent {
     enum rs_op_kind kind;
     int immediate;
-    size_t len_1, len_2;
+    int len_1, len_2;
 } rs_prototab_ent_t;
 
 extern const rs_prototab_ent_t rs_prototab[];
